@@ -1,4 +1,3 @@
-# encoding: utf-8
 """
 This module defines a convenience layer to access the MAD-X interpreter.
 
@@ -7,17 +6,15 @@ The most interesting class for users is :class:`Madx`.
 
 from __future__ import absolute_import
 
-from contextlib import contextmanager
+from contextlib import contextmanager, suppress
 from functools import wraps
 from itertools import product
 from numbers import Number
+import collections.abc as abc
 import os
 import subprocess
-
-try:
-    import collections.abc as abc
-except ImportError:                 # py2
-    import collections as abc
+import sys
+import warnings
 
 import numpy as np
 
@@ -25,10 +22,13 @@ from . import _rpc
 from . import util
 from .stream import AsyncReader
 
-try:
-    basestring
-except NameError:
-    basestring = str
+
+if sys.version_info < (3, 6):
+    _unsupported_version = (
+        "Support for python 3.5 and below will be removed in a future release!\n"
+        "If you need continued support for an older version, let us know at:\n"
+        "  https://github.com/hibtc/cpymad/issues")
+    warnings.warn(_unsupported_version, DeprecationWarning)
 
 
 __all__ = [
@@ -145,13 +145,13 @@ class Madx(object):
             m = Madx(stdout=sys.stdout)
         """
         # open history file
-        if isinstance(command_log, basestring):
+        if isinstance(command_log, str):
             command_log = CommandLog.create(command_log)
         self.reader = NullContext()
         # start libmadx subprocess
         if libmadx is None:
             if stdout is None:
-                from sys import stdout
+                stdout = sys.stdout
             if hasattr(stdout, 'write'):
                 try:
                     stdout = stdout.fileno()
@@ -193,8 +193,6 @@ class Madx(object):
         except (_rpc.RemoteProcessClosed, _rpc.RemoteProcessCrashed):
             return False
 
-    __nonzero__ = __bool__      # alias for python2 compatibility
-
     def __getattr__(self, name):
         """Resolve missing attributes as commands."""
         try:
@@ -206,11 +204,11 @@ class Madx(object):
 
     def quit(self):
         """Shutdown MAD-X interpreter and stop process."""
-        with util.suppress(AttributeError, RuntimeError):
+        with suppress(AttributeError, RuntimeError):
             self.input('quit;')
-        with util.suppress(AttributeError, RuntimeError):
+        with suppress(AttributeError, RuntimeError):
             self._service.close()
-        with util.suppress(AttributeError, RuntimeError):
+        with suppress(AttributeError, RuntimeError):
             self._process.wait()
         if hasattr(self._command_log, 'close'):
             self._command_log.close()
@@ -294,7 +292,7 @@ class Madx(object):
     def expr_vars(self, expr):
         """Find all variable names used in an expression. This does *not*
         include element attribute nor function names."""
-        if not isinstance(expr, basestring):
+        if not isinstance(expr, str):
             return []
         return [v for v in util.expr_symbols(expr)
                 if util.is_identifier(v)
@@ -622,11 +620,6 @@ class Sequence(object):
             other = other.name
         return self.name == other
 
-    # in py3 __ne__ delegates to __eq__, but we still need this for py2:
-    def __ne__(self, other):
-        """Comparison by sequence name."""
-        return not (self == other)
-
     __repr__ = __str__
 
     @property
@@ -874,7 +867,7 @@ class BaseElementList(object):
 
     def __getitem__(self, index):
         """Return element with specified index."""
-        if isinstance(index, basestring):
+        if isinstance(index, str):
             # allow element names to be passed for convenience:
             try:
                 index = self.index(index)
